@@ -7,7 +7,7 @@ from robotoff.types import PredictionType
 from robotoff.utils import text_file_iter
 from robotoff.utils.cache import CachedStore
 
-from .dataclass import OCRField, OCRRegex, OCRResult, get_text
+from .dataclass import OCRField, OCRRegex, OCRResult, get_match_bounding_box, get_text
 from .utils import generate_keyword_processor
 
 
@@ -20,10 +20,10 @@ def generate_trace_keyword_processor(labels: Optional[list[str]] = None):
 
 TRACES_REGEX = OCRRegex(
     re.compile(
-        r"(?:possibilit[ée] de traces|conditionné dans un atelier qui manipule|peut contenir(?: des traces)?|traces? [ée]ventuelles? d[e']|traces? d[e']|may contain)"
+        r"(?:possibilit[ée] de traces|conditionné dans un atelier qui manipule|peut contenir(?: des traces)?|traces? [ée]ventuelles? d[e']|traces? d[e']|may contain)",
+        re.I,
     ),
     field=OCRField.full_text_contiguous,
-    lowercase=True,
 )
 
 TRACE_KEYWORD_PROCESSOR_STORE = CachedStore(
@@ -50,11 +50,19 @@ def find_traces(content: Union[OCRResult, str]) -> list[Prediction]:
             captured, span_info=True
         ):
             match_str = captured[span_start:span_end]
+            data = {"text": match_str, "prompt": prompt, "notify": False}
+            if (
+                bounding_box := get_match_bounding_box(
+                    content, match.start(), match.end()
+                )
+            ) is not None:
+                data["bounding_box_absolute"] = bounding_box
+
             predictions.append(
                 Prediction(
                     type=PredictionType.trace,
                     value_tag=trace_tag,
-                    data={"text": match_str, "prompt": prompt, "notify": False},
+                    data=data,
                 )
             )
 
